<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="uk_UA">
<context>
    <name>About</name>
    <message>
        <location filename="../src/about.ui" line="26"/>
        <location filename="../src/about.cpp" line="37"/>
        <source>About</source>
        <translation>Про</translation>
    </message>
    <message>
        <location filename="../src/about.ui" line="82"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt; font-weight:700;&quot;&gt;UltimateDailyWallpaper&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/about.ui" line="89"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;Version: &lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/about.ui" line="133"/>
        <source>tab0</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/about.ui" line="178"/>
        <source>label_4</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/about.ui" line="191"/>
        <source>label_5</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/about.ui" line="204"/>
        <source>label_6</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/about.ui" line="230"/>
        <source>tab1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/about.ui" line="257"/>
        <source>TextLabel</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/about.ui" line="316"/>
        <source>pushButton_3</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/about.ui" line="335"/>
        <source>pushButton</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="38"/>
        <source>Currently used plugin</source>
        <translation>Використовуване розширення</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="44"/>
        <source>License: GPL-3.0+</source>
        <translation>Ліцензія: Загальна публічна ліцензія версія 3.0+</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="48"/>
        <source>Version: </source>
        <translation>Версія: </translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="54"/>
        <source>Patrice Coni</source>
        <translation>Patrice Coni</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="56"/>
        <source>Copyright © 2022 - </source>
        <translation>Авторське право © 2022 - </translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="62"/>
        <source>A wallpaper changer</source>
        <translation>Додаток для зміни шпалер</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="64"/>
        <source>Close</source>
        <translation>Вийти</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="65"/>
        <source>Visit website</source>
        <translation>Відвідайте веб-сайт</translation>
    </message>
    <message>
        <source>A simple application for changing wallpaper</source>
        <translation type="vanished">Просте додаток для зміни шпалер</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/mainwindow.cpp" line="93"/>
        <source>No connection to the internet.
The application will be closed.</source>
        <translation>Немає підключення до інтернету.
Заявка буде закрита.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="119"/>
        <source>Reset</source>
        <translation>Скинути</translation>
    </message>
    <message>
        <source>The folder that containing the plugins was not found. Do you want to set the folder manually?</source>
        <translation type="vanished">Папка, яка містить плагіни, не була знайдена. Хочете встановити папку вручну?</translation>
    </message>
    <message>
        <source>Select directory</source>
        <translation type="obsolete">Виберіть каталог</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="119"/>
        <source>The folder containing the plugins was not found. Do you want to set the folder manually?</source>
        <translation>Папку з плагінами не знайдено. Бажаєте встановити папку вручну?</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="125"/>
        <source>Select Plugin Folder</source>
        <translation>Виберіть папку плагіна</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="134"/>
        <source>No Plugins Found</source>
        <translation>Плагіни не знайдено</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="135"/>
        <source>The folder does not contain any plugin files (*.so). Please choose a valid plugin folder.</source>
        <translation>Папка не містить жодних файлів плагіна (*.so). Будь ласка, виберіть дійсну папку плагіна.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="323"/>
        <location filename="../src/mainwindow.cpp" line="334"/>
        <location filename="../src/mainwindow.cpp" line="811"/>
        <source>Error</source>
        <translation>Помилка</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="323"/>
        <source>No plugins found.</source>
        <translation>Плагінів не знайдено.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="329"/>
        <location filename="../src/mainwindow.cpp" line="806"/>
        <source>done.</source>
        <translation>зроблено.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="330"/>
        <location filename="../src/mainwindow.cpp" line="807"/>
        <source>Used plugin: </source>
        <translation>Використовуваний плагін: </translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="334"/>
        <location filename="../src/mainwindow.cpp" line="811"/>
        <source>Error while loading plugin.</source>
        <translation>Помилка під час завантаження плагіна.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="424"/>
        <source>An error was detected when starting the application.
The application will be closed.</source>
        <translation>An error was detected when starting the program.
The application will be closed.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="493"/>
        <source>No connection to the internet.</source>
        <translation>Немає підключення до інтернету.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="493"/>
        <source>Please check your internet connection.</source>
        <translation>Будь ласка, перевірте підключення до Інтернету.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="796"/>
        <source>&amp;Provider</source>
        <translation>&amp;Постачальника</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="834"/>
        <source>&amp;About this picture and license</source>
        <translation>&amp;Про цю картинку і ліцензію</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="838"/>
        <source>&amp;About this picture and copyright</source>
        <translation>&amp;Про цю картину і авторські права</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="845"/>
        <source>&amp;Download past pictures</source>
        <translation>&amp;Завантаження минулих зображень</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="849"/>
        <source>&amp;Load stored picture</source>
        <translation>&amp;Відкриття збереженого зображення</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="852"/>
        <source>&amp;Settings</source>
        <translation>&amp;Параметри</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="855"/>
        <source>&amp;About</source>
        <translation>&amp;Про</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="858"/>
        <source>&amp;Quit</source>
        <translation>&amp;Кинути</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="873"/>
        <source>No internet connection.</source>
        <translation>Немає підключення до інтернету.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="932"/>
        <source>Description: 
</source>
        <translation>Опис: 
</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1256"/>
        <source>Offline</source>
        <translation>Офлайн</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1257"/>
        <source>No internet connection available.</source>
        <translation>Немає підключення до інтернету.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1518"/>
        <source>Load plugin...</source>
        <translation>Запуск плагіна...</translation>
    </message>
</context>
<context>
    <name>PhotoBrowser</name>
    <message>
        <location filename="../src/photobrowser.ui" line="20"/>
        <location filename="../src/photobrowser.ui" line="58"/>
        <source>Load stored picture</source>
        <translation>Завантаження збереженого зображення</translation>
    </message>
    <message>
        <location filename="../src/photobrowser.ui" line="90"/>
        <location filename="../src/photobrowser.ui" line="187"/>
        <source>&amp;Set as wallpaper</source>
        <translation>&amp;Встановити в якості шпалер</translation>
    </message>
    <message>
        <location filename="../src/photobrowser.ui" line="174"/>
        <source>Select a photo</source>
        <translation>Виберіть фотографію</translation>
    </message>
    <message>
        <location filename="../src/photobrowser.ui" line="282"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:700;&quot;&gt;Select date: &lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:700;&quot;&gt;Виберіть дату:: &lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../src/photobrowser.ui" line="325"/>
        <source>&amp;Set current date</source>
        <translation>&amp;Установлення поточної дати</translation>
    </message>
    <message>
        <location filename="../src/photobrowser.ui" line="382"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Show photos of past days: &lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Переглянути фото минулих днів: &lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../src/photobrowser.ui" line="449"/>
        <source>&amp;Show pictures</source>
        <translation>&amp;Показати картинки</translation>
    </message>
    <message>
        <location filename="../src/photobrowser.cpp" line="209"/>
        <source>Error</source>
        <translation>Помилка</translation>
    </message>
    <message>
        <location filename="../src/photobrowser.cpp" line="209"/>
        <source>Error while loading plugin.</source>
        <translation>Помилка під час запуску плагіна.</translation>
    </message>
    <message>
        <location filename="../src/photobrowser.cpp" line="214"/>
        <source>Past pictures of the day (Wikimedia Commons)</source>
        <translation>Минулі фотографії дня (Вікісховище)</translation>
    </message>
    <message>
        <location filename="../src/photobrowser.cpp" line="263"/>
        <source>Get more information</source>
        <translation>Отримати більше інформації</translation>
    </message>
    <message>
        <location filename="../src/photobrowser.cpp" line="430"/>
        <source>Details</source>
        <translation>Деталі</translation>
    </message>
    <message>
        <location filename="../src/photobrowser.cpp" line="434"/>
        <source>Please select a picture.</source>
        <translation>Будь ласка, виберіть зображення.</translation>
    </message>
    <message>
        <location filename="../src/photobrowser.cpp" line="442"/>
        <source>Title: </source>
        <translation>Назва: </translation>
    </message>
    <message>
        <location filename="../src/photobrowser.cpp" line="448"/>
        <source>Description: </source>
        <translation>Опис: </translation>
    </message>
    <message>
        <location filename="../src/photobrowser.cpp" line="460"/>
        <source>Picture size:</source>
        <translation>Розмір картинки:</translation>
    </message>
    <message>
        <location filename="../src/photobrowser.cpp" line="470"/>
        <source>Preview:</source>
        <translation>Попередній перегляд:</translation>
    </message>
    <message>
        <location filename="../src/photobrowser.cpp" line="508"/>
        <source>Download in progress...</source>
        <translation>Завантаження триває...</translation>
    </message>
    <message>
        <location filename="../src/photobrowser.cpp" line="551"/>
        <source>The entered date must not be in the future.</source>
        <translation>Введеної дати не повинно бути в майбутньому.</translation>
    </message>
    <message>
        <location filename="../src/photobrowser.cpp" line="641"/>
        <source>Working in progress...</source>
        <translation>У процесі...</translation>
    </message>
</context>
<context>
    <name>QProgressDialog</name>
    <message>
        <source>Download in progress...</source>
        <translation type="vanished">Завантаження триває...</translation>
    </message>
    <message>
        <source>Working in progress...</source>
        <translation type="vanished">У процесі...</translation>
    </message>
</context>
<context>
    <name>SettingsWindow</name>
    <message>
        <location filename="../src/settingswindow.ui" line="23"/>
        <source>Settings</source>
        <translation>Параметри</translation>
    </message>
    <message>
        <location filename="../src/settingswindow.ui" line="37"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Location to save background photos: &lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Розташування для збереження фонових фотографій: &lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../src/settingswindow.ui" line="55"/>
        <source>Choose</source>
        <translation>Вибирати</translation>
    </message>
    <message>
        <location filename="../src/settingswindow.ui" line="72"/>
        <source>Delete wallpapers older than (days): </source>
        <translation>Видалення фонових зображень старше (днів): </translation>
    </message>
    <message>
        <location filename="../src/settingswindow.ui" line="121"/>
        <source>Change desktop background photo automatically</source>
        <translation>Автоматична зміна фотографії тла робочого стола</translation>
    </message>
    <message>
        <location filename="../src/settingswindow.ui" line="141"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Time of day for changing wallpaper automatically: &lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Час доби для автоматичної зміни шпалер: &lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../src/settingswindow.ui" line="181"/>
        <source>Run Application at startup</source>
        <translation>Запуск програми під час запуску</translation>
    </message>
    <message>
        <location filename="../src/settingswindow.ui" line="198"/>
        <source>Change lock screen wallpaper if possible</source>
        <translation>Змінити шпалери на екрані блокування, якщо це можливо</translation>
    </message>
    <message>
        <location filename="../src/settingswindow.ui" line="240"/>
        <location filename="../src/settingswindow.cpp" line="176"/>
        <source>Reset</source>
        <translation>Скинути</translation>
    </message>
    <message>
        <location filename="../src/settingswindow.ui" line="272"/>
        <source>Save settings</source>
        <translation>Рятувати</translation>
    </message>
    <message>
        <location filename="../src/settingswindow.ui" line="291"/>
        <source>Cancel</source>
        <translation>Скасувати</translation>
    </message>
    <message>
        <location filename="../src/settingswindow.cpp" line="141"/>
        <source>Save changes</source>
        <translation>Рятувати</translation>
    </message>
    <message>
        <location filename="../src/settingswindow.cpp" line="141"/>
        <source>The application will be restart for the changes to take effect. Do you want save the changes?</source>
        <translation>Додаток буде перезапущено, щоб зміни вступили в силу. Хочете зберегти зміни?</translation>
    </message>
    <message>
        <location filename="../src/settingswindow.cpp" line="155"/>
        <source>Select directory</source>
        <translation>Виберіть каталог</translation>
    </message>
    <message>
        <location filename="../src/settingswindow.cpp" line="176"/>
        <source>This will reset all settings to the default settings. All existing wallpapers will be deleted. Do you want to continue?</source>
        <translation>Це призведе до скидання всіх налаштувань до налаштувань за замовчуванням. Всі існуючі шпалери будуть видалені. Хочете продовжити?</translation>
    </message>
</context>
<context>
    <name>setWallpaper</name>
    <message>
        <location filename="../src/setwallpaper.cpp" line="207"/>
        <source>Error: Failed to set wallpaper on macOS.</source>
        <translation>Не вдалося встановити шпалери.</translation>
    </message>
    <message>
        <location filename="../src/setwallpaper.cpp" line="218"/>
        <source>Error - Failed to set wallpaper.</source>
        <translation>Не вдалося встановити шпалери.</translation>
    </message>
</context>
</TS>
